Package: lemon
Type: Package
Title: Freshing Up your 'ggplot2' Plots
URL: https://github.com/stefanedwards/lemon
BugReports: https://github.com/stefanedwards/lemon/issues
Version: 0.5.2
Authors@R: c(
    person('Stefan McKinnon', 'Edwards', email='sme@iysik.com',
    comment=c(ORCID='0000-0002-4628-8148'),
    role=c('aut','ctb','cre')),
    person('Baptiste','Auguie', role='ctb',
    comment='For g_legend and grid_arrange_shared_legend'),
    person('Shaun','Jackman', role='ctb',
    comment='For grid_arrange_shared_legend'),
    person("Hadley", "Wickham", , "hadley@rstudio.com", "ctb",
    comment='ggplot2 functions'),
    person("Winston", "Chang", , "winston@rstudio.com", "ctb",
    comment='ggplot2 functions')
    )
Description: Functions for working with legends and axis lines of 'ggplot2',
    facets that repeat axis lines on all panels, and some 'knitr' extensions.
Depends: R (>= 3.1.0)
Imports: ggplot2 (>= 3.4.2), plyr, grid, gridExtra, gtable, knitr (>=
        1.12), lattice, scales
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.3.2
Collate: 'ggplot2.r' 'lemon-plot.r' 'axis-annotation.r' 'brackets.R'
        'coord-flex.r' 'coord-capped.r' 'dot.r' 'facet-rep-lab.r'
        'facet-wrap.r' 'geom-pointline.r' 'lemon_print.r'
        'geom-siderange.r' 'grob_utils.r' 'gtable_show-.r'
        'guides-axis.r' 'legends.r' 'lemon.r' 'scale-symmetric.r'
Suggests: rmarkdown, stringr, ggh4x, dplyr, testthat, vdiffr,
        diffviewer
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2025-09-04 10:55:16 UTC; root
Author: Stefan McKinnon Edwards [aut, ctb, cre] (ORCID:
    <https://orcid.org/0000-0002-4628-8148>),
  Baptiste Auguie [ctb] (For g_legend and grid_arrange_shared_legend),
  Shaun Jackman [ctb] (For grid_arrange_shared_legend),
  Hadley Wickham [ctb] (ggplot2 functions),
  Winston Chang [ctb] (ggplot2 functions)
Maintainer: Stefan McKinnon Edwards <sme@iysik.com>
Repository: CRAN
Date/Publication: 2025-09-04 11:50:02 UTC
Built: R 4.6.0; ; 2026-04-28 01:57:49 UTC; unix
