# Generated by roxygen2: do not edit by hand

S3method(ggplot_add,axis_annotation)
S3method(ggplot_build,lemon_plot)
S3method(ggplot_gtable,built_lemon)
S3method(lemon_print,data.frame)
S3method(lemon_print,table)
export(.dot)
export(.dot2)
export(CoordFlexCartesian)
export(CoordFlexFixed)
export(CoordFlexFlipped)
export(FacetGridRepeatLabels)
export(FacetWrapRepeatLabels)
export(GeomPointLine)
export(GeomPointPath)
export(GeomSideRange)
export(annotate_x_axis)
export(annotate_y_axis)
export(as.lemon_plot)
export(brackets_horisontal)
export(brackets_horizontal)
export(brackets_vertical)
export(capped_horisontal)
export(capped_horizontal)
export(capped_vertical)
export(coord_capped_cart)
export(coord_capped_flip)
export(coord_flex_cart)
export(coord_flex_fixed)
export(coord_flex_flip)
export(facet_rep_grid)
export(facet_rep_wrap)
export(g_legend)
export(geom_pointline)
export(geom_pointpath)
export(geom_siderange)
export(get_panel_params)
export(get_panel_x_range)
export(get_panel_y_range)
export(grid_arrange_shared_legend)
export(gtable_show_grill)
export(gtable_show_names)
export(guidebox_as_column)
export(lemon_print)
export(render_gpar)
export(reposition_legend)
export(scale_x_symmetric)
export(scale_y_symmetric)
if(getRversion() < "4.4")  export("%||%")
import(ggplot2)
import(grDevices)
import(grid)
import(gridExtra)
import(gtable)
import(knitr)
import(lattice)
import(plyr)
import(scales)
importFrom(plyr,defaults)
