# Crate Version Manager (CVM)

Hello and welcome! This folder has been automatically generated by `cvm`, a build tool that works
with multi-crate repos, or single-crate repos to help you version and publish your code. You can
find the full documentation for it [in our repository](https://github.com/lucasaarch/cvm)